import { defineStore } from "pinia";
import storage from "store";
import UaParser from "ua-parser-js";
import type { IResult as UaResult } from "ua-parser-js";
import router from "@/router";

/**
 * 用户信息-类型
 */
export interface UserInfo {
  accessToken: string;
  authed: number;
  childId: number;
  company: string;
  domain: string;
  equipmentFlag: number;
  headImg: string;
  logo: string;
  mobile: string;
  name: string;
  openid: string;
  placeId: number;
  placeName: string;
  role: number;
  shortName: string;
  tradeAuth: number;
  truckNo: number;
  userId: number;
  walletCode: number;
}

export interface UserState {
  userInfo: UserInfo;
  ua: UaResult;
}

/** userInfo 存储信息 字段名 */
export const USER_INFO: "USER_INFO" = "USER_INFO";

/** token 字段名 */
export const ACCESS_TOKEN: "accessToken" = "accessToken";
/** userId 字段名 */
export const USER_ID: "userId" = "userId";

const defaultUserInfo = {
  accessToken: "",
  authed: 0,
  childId: 0,
  company: "",
  domain: "",
  equipmentFlag: 0,
  headImg: "",
  logo: "",
  mobile: "",
  name: "",
  openid: "",
  placeId: 0,
  placeName: "",
  role: 0,
  shortName: "",
  tradeAuth: 0,
  truckNo: 0,
  userId: 0,
  walletCode: 0,
};

export const useUserStore = defineStore({
  id: "clxUser",
  state: (): UserState => ({
    userInfo: { ...defaultUserInfo },
    ua: new UaParser().getResult(),
  }),
  actions: {
    setUserInfo(payload: UserInfo) {
      this.userInfo = payload;
      storage.set(USER_INFO, this.userInfo || {});
    },
    resetUserInfo() {
      this.userInfo = { ...defaultUserInfo };
    },
    async getUserInfo() {
      const userInfo = (storage.get(USER_INFO) as UserInfo) || {};
      const userID = userInfo?.userId;
      if (!userID) {
        // 异步调用查询用户信息接口
      }
    },
    async login() {
      // 调用登陆接口
      // this.setUserInfo(payload);
      // router.push({ path: '/' });
    },
    async logout() {
      // 调用退出登陆接口
      this.resetUserInfo();
      router.push({ name: "login" });
    },
    async verification(token: string) {
      // 调用 token 验证接口
      return Promise.resolve(token);
    },
  },
});
